aboutsummaryrefslogtreecommitdiff
path: root/devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py
diff options
context:
space:
mode:
authorantoniou792018-12-28 23:36:28 +0200
committerEugene Sandulenko2019-01-06 17:12:02 +0100
commitcd764ac86ea03d24aa57b0fdcb2c64f46cb65aa7 (patch)
tree0f47037f37d31bceef44c2504c03d06c424b3d34 /devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py
parent14d65c49b763d4e70179f7e8e259b4c4b901fe27 (diff)
downloadscummvm-rg350-cd764ac86ea03d24aa57b0fdcb2c64f46cb65aa7.tar.gz
scummvm-rg350-cd764ac86ea03d24aa57b0fdcb2c64f46cb65aa7.tar.bz2
scummvm-rg350-cd764ac86ea03d24aa57b0fdcb2c64f46cb65aa7.zip
DEVTOOLS: BladeRunner readme update
Also fixed broken modes for fontCreator and quotesSpreadsheetCreator scripts
Diffstat (limited to 'devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py')
-rw-r--r--devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py21
1 files changed, 15 insertions, 6 deletions
diff --git a/devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py b/devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py
index bf62889bb1..37d92ceb6e 100644
--- a/devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py
+++ b/devtools/create_bladerunner/subtitles/mixResourceCreator/packBladeRunnerMIXFromPCTLKXLS04.py
@@ -15,6 +15,7 @@ ctypesLibFound = False
csvLibFound = False
xlrdLibFound = False
reLibFound = False
+structLibFound = False
try:
import shutil
@@ -51,7 +52,14 @@ except ImportError:
else:
reLibFound = True
-if (not shutilLibFound) or (not ctypesLibFound) or (not csvLibFound) or (not xlrdLibFound) or (not reLibFound):
+try:
+ import struct
+except ImportError:
+ print "Error:: struct python library is required to be installed!"
+else:
+ structLibFound = True
+
+if (not shutilLibFound) or (not ctypesLibFound) or (not csvLibFound) or (not xlrdLibFound) or (not reLibFound) or (not structLibFound):
sys.stdout.write("Error:: Errors were found when trying to import required python libraries\n")
sys.exit(1)
@@ -64,6 +72,7 @@ from struct import *
company_email = "classic.adventures.in.greek@gmail.com"
app_version = "0.70"
app_name = "packBladeRunnerMIXFromPCTLKXLS"
+app_wrapper_name = "mixResourceCreator.py"
app_name_spaced = "Blade Runner MIX Resource Creator"
app_short_desc = "Get a TRE file from spoken in-game quotes"
numOfSpokenQuotes = 0
@@ -735,9 +744,9 @@ def main(argsCL):
print "Preparatory steps:"
print "1. Copy the BladeRunnerPCTLK.xls file (latest version, downloaded from Google Sheets) in some folder on your PC."
print "--------------------"
- print "%s takes 1 mandatory argument:" % (app_name_spaced)
+ print "%s takes 1 mandatory argument:" % (app_wrapper_name)
print "Valid syntax: "
- print "%s -x path_to_BladeRunnerPCTLK_xls [-ian path_to_actornames_txt] [-cft path_to_configureFontsTranslation_txt] [--trace]" % (app_name)
+ print "%s -x path_to_BladeRunnerPCTLK_xls [-ian path_to_actornames_txt] [-cft path_to_configureFontsTranslation_txt] [--trace]" % (app_wrapper_name)
print "-x is followed by the path to the excel file with the subtitle quotes."
print "-ian is followed by the path to actornames.txt, if it's not in the current working directory."
print "-cft is followed by the path to configureFontsTranslation.txt, if it's not in the current working directory."
@@ -787,9 +796,9 @@ def main(argsCL):
invalidSyntax = True
if invalidSyntax == True:
- print "Invalid syntax\n Try: \n %s --help for more info \n %s --version for version info " % (app_name, app_name)
+ print "Invalid syntax\n Try: \n %s --help for more info \n %s --version for version info " % (app_wrapper_name, app_wrapper_name)
print "Valid syntax: "
- print "%s -x path_to_BladeRunnerPCTLK_xls [-ian path_to_actornames_txt] [-cft path_to_configureFontsTranslation_txt] [--trace]" % (app_name)
+ print "%s -x path_to_BladeRunnerPCTLK_xls [-ian path_to_actornames_txt] [-cft path_to_configureFontsTranslation_txt] [--trace]" % (app_wrapper_name)
print "-x is followed by the path to the excel file with the subtitle quotes."
print "-ian is followed by the path to actornames.txt, if it's not in the current working directory."
print "-cft is followed by the path to configureFontsTranslation.txt, if it's not in the current working directory."
@@ -812,5 +821,5 @@ if __name__ == "__main__":
main(sys.argv[0:])
else:
## debug
#print 'Debug:: %s was imported from another module' % (app_name)
pass
@@ -812,5 +821,5 @@ if __name__ == "__main__":
else:
## debug
- #print 'Debug:: %s was imported from another module' % (app_name)
+ #print 'Debug:: %s was imported from another module' % (app_wrapper_name)
pass